Style Commandments
==================

Read the OpenStack Style Commandments http://docs.openstack.org/developer/hacking/

Mistral Specific Commandments
-----------------------------

- [M318] Change assertEqual(A, None) or assertEqual(None, A) by optimal assert
  like assertIsNone(A)
